@@ -1,7 +1,7 @@
 /*
  * The SIP module interface.
  *
- * Copyright (c) 2022 Riverbank Computing Limited <info@riverbankcomputing.com>
+ * Copyright (c) 2023 Riverbank Computing Limited <info@riverbankcomputing.com>
  *
  * This file is part of SIP.
  *
@@ -24,8 +24,8 @@
 #include <Python.h>
 
 /* Sanity check on the Python version. */
-#if PY_VERSION_HEX < 0x03070000
-#error "This version of wx.siplib requires Python v3.7 or later"
+#if PY_VERSION_HEX < 0x03080000
+#error "This version of wx.siplib requires Python v3.8 or later"
 #endif
 
 
@@ -45,17 +45,28 @@ extern "C" {
 
 /* The version of the ABI. */
 #define SIP_ABI_MAJOR_VERSION       12
-#define SIP_ABI_MINOR_VERSION       11
+#define SIP_ABI_MINOR_VERSION       14
 #define SIP_MODULE_PATCH_VERSION    0
 
 
 /*
  * The change history of the ABI.
  *
+ * v12.14
+ *  - Python v3.8 or later is required.
+ *
+ * v12.13
+ *  - Added support for Python v3.12.
+ *  - Added sipPyTypeDictRef().
+ *  - Deprecated sipPyTypeDict().
+ *
+ * v12.12
+ *  - Added the '#' conversion character to the argument parsers.
+ *
  * v12.11
  *  - Published the 'array' type.
  *  - Added the ctd_sizeof, ctd_array_delete members to sipClassTypeDef.
- *  - Added the '>' conversion character to sipParseArgs().
+ *  - Added the '>' conversion character to the argument parsers.
  *
  * v12.10
  *  - Python v3.7 or later is required.
@@ -70,8 +81,8 @@ extern "C" {
 
 
 /* The version of the code generator. */
-#define SIP_VERSION                 0x60602
-#define SIP_VERSION_STR             "6.6.2"
+#define SIP_VERSION                 0x60803
+#define SIP_VERSION_STR             "6.8.3"
 
 /* These are all dependent on the user-specified name of the sip module. */
 #define _SIP_MODULE_FQ_NAME         "wx.siplib"
@@ -1665,6 +1676,11 @@ typedef struct _sipAPIDef {
     PyObject *(*api_is_py_method_12_8)(sip_gilstate_t *gil, char *pymc,
             sipSimpleWrapper **sipSelfp, const char *cname, const char *mname);
     sipExceptionHandler (*api_next_exception_handler)(void **statep);
+
+    /*
+     * The following are part of the public API.
+     */
+    PyObject *(*api_py_type_dict_ref)(PyTypeObject *);
 } sipAPIDef;
 
 const sipAPIDef *sip_init_library(PyObject *mod_dict);
